#!/usr/bin/env node
/*!
* distribute.it
* Copyright (c) 2011 Peter Sunde <peter.sunde@gmail.com>
* MIT Licensed
*/

var express = require('express')
  , redis = require('redis').createClient()
  , csrf = require('express-csrf')
  , connect = require('connect')
  , redisStore = require('connect-redis')(connect)
  , ejs = require('ejs')
  , urlParser = require('url')
  , torrentServer = require('./lib/tracker/server.js')
  , routeController = new require('./lib/core/routecontroller.js').routeController
  , argv = require('optimist')
  .usage("Usage: $0 --ip 0.0.0.0 --port 80")
  .demand(['ip', 'port'])
  .argv;

// obtain a reference to express
var app = module.exports = express.createServer();

// create a new route controller
routeController = new routeController();
 
// skeleton for http errors
function NotFound(msg){
    this.name = 'NotFound';
    Error.call(this, msg);
    Error.captureStackTrace(this, arguments.callee);
}

NotFound.prototype.__proto__ = Error.prototype;

// configuration
app.configure(function(){
  app.set('title', 'Distribute.it');
  app.set('views', __dirname + '/views');
  app.set('view engine', 'ejs');
  app.use(express.logger('  \033[90m:method\033[0m \033[36m:url\033[0m \033[90m:response-timems\033[0m'));
  app.use(express.bodyParser());
  app.use(express.cookieParser());
  app.use(express.session({ secret: "kljAKSLJElKJ#LkjLK#Jlkam.,m", store: new redisStore }))
  app.use(express.methodOverride());
  app.use(app.router);
  app.use(express['static'](__dirname + '/public'));
  app.use(express.errorHandler({ showStack: true, dumpExceptions: true }));
});

// dynamic handlers
app.dynamicHelpers({
    // protection against csrf attacks
    csrf: csrf.token
});

// registers all views
routeController.require('./views/src', { 
    database: redis,
    app: app,
    torrent: torrentServer
});

// listen
app.listen(argv.port, argv.ip);

// okay we're done
console.log("Express server listening on port %d", app.address().port);